@@ -1,17 +1,12 @@
 /*
- * Copyright Stalwart Labs, Minter Ltd. See the COPYING
- * file at the top-level directory of this distribution.
+ * SPDX-FileCopyrightText: 2020 Stalwart Labs LLC <hello@stalw.art>
  *
- * Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
- * https://www.apache.org/licenses/LICENSE-2.0> or the MIT license
- * <LICENSE-MIT or https://opensource.org/licenses/MIT>, at your
- * option. This file may not be copied, modified, or distributed
- * except according to those terms.
+ * SPDX-License-Identifier: Apache-2.0 OR MIT
  */
 
 use std::io::{self, Write};
 
-use super::{base64::base64_encode, quoted_printable::quoted_printable_encode};
+use super::{base64::base64_encode_mime, quoted_printable::quoted_printable_encode};
 
 pub enum EncodingType {
     Base64,
@@ -84,7 +79,7 @@ pub fn rfc2047_encode(input: &str, mut output: impl Write) -> io::Result<usize>
     Ok(match get_encoding_type(input.as_bytes(), true, false) {
         EncodingType::Base64 => {
             output.write_all(b"\"=?utf-8?B?")?;
-            let bytes_written = base64_encode(input.as_bytes(), &mut output, true)? + 14;
+            let bytes_written = base64_encode_mime(input.as_bytes(), &mut output, true)? + 14;
             output.write_all(b"?=\"")?;
             bytes_written
         }
